/// <reference types="node" />
import { IncomingMessage, ServerResponse } from "http";
import { IBody } from "./body";
import { ErrorWithStatusCode } from "./errors/status";
import { Middleware } from "./index";
import { IRouteOptions } from "./route";
export declare enum Methods {
    GET = "get",
    POST = "post",
    DELETE = "delete",
    PUT = "put",
    PATCH = "patch",
    OPTIONS = "options"
}
export interface ICtx {
    req: IncomingMessage;
    res: ServerResponse;
    matches?: RegExpExecArray[];
    path: string;
    data: any;
    body?: IBody;
    query: any;
    statusCode?: number;
}
export declare type Handler = (ctx: ICtx) => Promise<void> | void;
export declare type Middleware = (ctx: ICtx) => (() => void) | Promise<void> | void;
export declare type ErrorHandler = Handler | ((ctx: ICtx, error: Error | ErrorWithStatusCode) => Promise<any> | any);
declare type RouteHandler_ = Router | Handler;
export declare type RouteHandler = RouteHandler_ | RouteHandler_[];
declare type RouteAdder = (path: string, handler: RouteHandler, options?: IRouteOptions) => Router;
export declare class Router {
    errorHandler: ErrorHandler | undefined;
    get: RouteAdder;
    post: RouteAdder;
    delete: RouteAdder;
    put: RouteAdder;
    patch: RouteAdder;
    private routes;
    private middlewares;
    child: (path: string, handler?: Router | [Router | null, Middleware | Middleware[]] | undefined, options?: IRouteOptions | undefined) => Router;
    route: (method: Methods | Methods[] | undefined, path: string, handler: RouteHandler, options?: IRouteOptions | undefined) => this;
    any: (path: string, handler: RouteHandler, options?: IRouteOptions | undefined) => this;
    middleware: (middleware: Middleware | Middleware[]) => this;
    handle: Handler;
}
export {};
